document.addEventListener('DOMContentLoaded', function() {
    const fromValue = document.getElementById('fromValue');
    const toValue = document.getElementById('toValue');
    const fromUnit = document.getElementById('fromUnit');
    const toUnit = document.getElementById('toUnit');
    const swapBtn = document.getElementById('swapBtn');

    const conversionRates = {
        meters: 1,
        kilometers: 1000,
        centimeters: 0.01,
        millimeters: 0.001,
        miles: 1609.34,
        yards: 0.9144,
        feet: 0.3048,
        inches: 0.0254
    };

    function convert() {
        if (!fromValue.value) {
            toValue.value = '';
            return;
        }

        const inputValue = parseFloat(fromValue.value);
        const fromRate = conversionRates[fromUnit.value];
        const toRate = conversionRates[toUnit.value];
        
        const result = (inputValue * fromRate) / toRate;
        toValue.value = result.toFixed(6);
    }

    function swapUnits() {
        const tempUnit = fromUnit.value;
        fromUnit.value = toUnit.value;
        toUnit.value = tempUnit;
        
        const tempValue = fromValue.value;
        fromValue.value = toValue.value;
        toValue.value = tempValue;
        
        convert();
    }

    // Event listeners
    fromValue.addEventListener('input', convert);
    fromUnit.addEventListener('change', convert);
    toUnit.addEventListener('change', convert);
    swapBtn.addEventListener('click', swapUnits);

    // Set initial different units
    fromUnit.value = 'meters';
    toUnit.value = 'feet';
});
